
dialogId("dlg-x-poster1", "font_poster", "Greetings from the rubbish heap to our beloved boss.")
dialogStr("Groeten van de vuilnisbelt aan onze allerbeste baas.")


dialogId("dlg-x-poster2", "font_poster", "Yours sincerely")
dialogStr("Met vriendelijke groeten.")


dialogId("dlg-x-poster3", "font_poster", "Agents")
dialogStr("Agenten")


dialogId("dlg-x-poster4", "font_poster", "PS: It's great to be here. We irradiate ourselves and swim in the sea a lot. We have many new friends.")
dialogStr("PS: Het is hier geweldig. We bestralen onszelf en zwemmen veel in de zee. We hebben een hoop nieuwe vrienden gemaakt.")

